==> 0.3.zip: micro-orm/src/Fufle/ORM/Model.php <==
<?php

namespace Fufle\ORM;

use Fufle\ORM\Database\ConnectionManager;

abstract class Model {
    protected static string $primaryKey = 'id';
    protected static ?string $table = null;
    private static ?IQuery $query = null;

    protected static array $fields = [];

    public function toArray(): array {
        $array = [];
        $fields = static::$fields;
        foreach($fields as $field) {
            if ($this->{$field} ?? null !== null) {
                $array[$field] = $this->{$field};
            }
        }
        return $array;
    }

    protected static function QueryModel() {
        if (false && self::$query === null && self::class !== static::class) {
            self::$query = static::SetQueryModel();
        }
        return self::$query;
    }

    public static function GetTableName() {
        if (static::$table === null) {
            static::$table = basename(str_replace('\\', '/', get_called_class())) . 's';
        }
        return static::$table;
    }

    public static function GetPrimaryKey() {
        return static::$primaryKey;
    }

    public static function Get(int $id) {
        return self::Query(
            static::QueryModel()->Get(),
            [$id]);
    }

    protected static function Query(string $sql, array|object $params = []) {
        return ConnectionManager::Query(
            $sql,
            $params,
            get_called_class());
    }

    protected static function QueryAll(string $sql, array|object $params = []) {
        return ConnectionManager::QueryAll(
            $sql,
            $params,
            get_called_class());
    }
    
    abstract public static function SetQueryModel(): IQuery;
}

==> 0.7.zip: micro-orm/src/Fufle/ORM/Model.php <==
<?php

namespace Fufle\ORM;

use Fufle\ORM\Database\ConnectionManager;

abstract class Model {
    protected static string $primaryKey = 'id';
    protected static ?string $table = null;
    protected static ?IQuery $query = null;

    protected static array $fields = [];

    public function toArray(): array {
        $array = [];
        $fields = static::$fields;
        foreach($fields as $field) {
            if (isset($this->{$field})) {
                $array[$field] = $this->{$field};
            }
        }
        return $array;
    }

    protected static function QueryModel() {
        return static::SetQueryModel();
    }

    public static function GetTableName() {
        if (static::$table === null) {
            static::$table = basename(str_replace('\\', '/', get_called_class())) . 's';
        }
        return static::$table;
    }

    public static function GetPrimaryKey() {
        return static::$primaryKey;
    }

    public static function Get(int $id) {
        return self::Query(
            static::QueryModel()->Get(),
            [$id]);
    }

    protected static function Query(string $sql, array|object $params = []) {
        $result = ConnectionManager::Query(
            $sql,
            $params,
            get_called_class());
        if (!$result) {
            return null;
        }
        return $result;
    }

    protected static function QueryAll(string $sql, array|object $params = []) {
        $result = ConnectionManager::QueryAll(
            $sql,
            $params,
            get_called_class());
        if (!$result) {
            return [];
        }
        return $result;
    }

    abstract public static function SetQueryModel(): IQuery;
}
